==> haskell-tzdata-0.2.20250115.0-96.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tzdata.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tzdata
version:              0.2.20250115.0
visibility:           public
id:                   tzdata-0.2.20250115.0-FaaHBpCDERQJhkXq9KdwIj
key:                  tzdata-0.2.20250115.0-FaaHBpCDERQJhkXq9KdwIj
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tzdata
synopsis:             Time zone database (as files and as a module)
description:
    The goal of this package is to distribute the standard Time Zone
    Database in a cabal package, so that it can be used in Haskell
    programs uniformly on all platforms.

    This package currently ships the @2025a@ version of the time zone
    database.  The version of the time zone database shipped is always
    reflected in the version of this package: @x.y.YYYYMMDD.z@, then
    @YYYYMMDD@ is the official release date of time zone database.

    This version contains the "fat" variant of the time zone files (which is not
    the default for the upstream since @2020b@) to facilitate the transition. The
    next major version (@0.3@) will ship the "slim" variant.

    See: <http://www.iana.org/time-zones> for more info about the time
    zone database.

    See also the @tz@ package <http://hackage.haskell.org/package/tz> or
    the @timezone-olson@ and @timezone-series@ packages that provide
    facilities to /use/ the data shipped here. (The @tz@ package
    automatically installs this package.)

category:             Data
abi:                  0ea5103abbd06beb6539e730b850eb76
exposed:              True
exposed-modules:      Data.Time.Zones.DB Data.Time.Zones.Files
hidden-modules:       Paths_tzdata
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tzdata-0.2.20250115.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tzdata-0.2.20250115.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tzdata-0.2.20250115.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tzdata
hs-libraries:         HStzdata-0.2.20250115.0-FaaHBpCDERQJhkXq9KdwIj
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-tzdata/html/tzdata.haddock
haddock-html:         /usr/share/doc/haskell-tzdata/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tzdata-0.2.20250115.0-97-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tzdata.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tzdata
version:              0.2.20250115.0
visibility:           public
id:                   tzdata-0.2.20250115.0-3UxDys6VWHo1x0vhEee3Ah
key:                  tzdata-0.2.20250115.0-3UxDys6VWHo1x0vhEee3Ah
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tzdata
synopsis:             Time zone database (as files and as a module)
description:
    The goal of this package is to distribute the standard Time Zone
    Database in a cabal package, so that it can be used in Haskell
    programs uniformly on all platforms.

    This package currently ships the @2025a@ version of the time zone
    database.  The version of the time zone database shipped is always
    reflected in the version of this package: @x.y.YYYYMMDD.z@, then
    @YYYYMMDD@ is the official release date of time zone database.

    This version contains the "fat" variant of the time zone files (which is not
    the default for the upstream since @2020b@) to facilitate the transition. The
    next major version (@0.3@) will ship the "slim" variant.

    See: <http://www.iana.org/time-zones> for more info about the time
    zone database.

    See also the @tz@ package <http://hackage.haskell.org/package/tz> or
    the @timezone-olson@ and @timezone-series@ packages that provide
    facilities to /use/ the data shipped here. (The @tz@ package
    automatically installs this package.)

category:             Data
abi:                  b3058b84f37b5074a18e02c205bb4a61
exposed:              True
exposed-modules:      Data.Time.Zones.DB Data.Time.Zones.Files
hidden-modules:       Paths_tzdata
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tzdata-0.2.20250115.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tzdata-0.2.20250115.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tzdata-0.2.20250115.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tzdata
hs-libraries:         HStzdata-0.2.20250115.0-3UxDys6VWHo1x0vhEee3Ah
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-tzdata/html/tzdata.haddock
haddock-html:         /usr/share/doc/haskell-tzdata/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
